import type { HtmlElementPosition, InferDOMType } from './types/index';
/** calculate available space for each side of the DOM element */
export declare function calculateAvailableSpace(element: HTMLElement): {
    top: number;
    bottom: number;
    left: number;
    right: number;
};
/**
 * Create a DOM Element with any optional attributes or properties.
 * It will only accept valid DOM element properties that `createElement` would accept.
 * For example: `createDomElement('div', { className: 'my-css-class' })`,
 * for style or dataset you need to use nested object `{ style: { display: 'none' }}
 * The last argument is to optionally append the created element to a parent container element.
 * @param {String} tagName - html tag
 * @param {Object} options - element properties
 * @param {[Element]} appendToParent - parent element to append to
 */
export declare function createDomElement<T extends keyof HTMLElementTagNameMap, K extends keyof HTMLElementTagNameMap[T]>(tagName: T, elementOptions?: null | {
    [P in K]: InferDOMType<HTMLElementTagNameMap[T][P]>;
}, appendToParent?: Element): HTMLElementTagNameMap[T];
/**
 * Loop through all properties of an object and nullify any properties that are instanceof HTMLElement,
 * if we detect an array then use recursion to go inside it and apply same logic
 * @param obj - object containing 1 or more properties with DOM Elements
 */
export declare function destroyAllElementProps(obj: any): void;
/**
 * Empty a DOM element by removing all of its DOM element children leaving with an empty element (basically an empty shell)
 * @return {object} element - updated element
 */
export declare function emptyElement<T extends Element = Element>(element?: T | null): T | undefined | null;
/**
 * From a DocumentFragment, get the innerHTML or outerHTML of all child elements.
 * We can get the HTML by looping through all fragment `childNodes`
 */
export declare function getHTMLFromFragment(input: DocumentFragment, type?: 'innerHTML' | 'outerHTML'): string;
/** Get offset of HTML element relative to a parent element */
export declare function getOffsetRelativeToParent(parentElm: HTMLElement | null, childElm: HTMLElement | null): {
    top: number;
    right: number;
    bottom: number;
    left: number;
} | undefined;
/** Get HTML element offset with pure JS */
export declare function getOffset(elm?: HTMLElement | null): HtmlElementPosition | undefined;
export declare function getInnerSize(elm: HTMLElement, type: 'height' | 'width'): number;
/** Get a DOM element style property value by calling getComputedStyle() on the element */
export declare function getStyleProp(elm: HTMLElement, property: string): string | null;
export declare function findFirstAttribute(inputElm: Element | null | undefined, attributes: string[]): string | null;
/**
 * Provide a width as a number or a string and find associated value in valid css style format or use default value when provided (or "auto" otherwise).
 * @param {Number|String} inputWidth - input width, could be a string or number
 * @param {Number | String} defaultValue [defaultValue=auto] - optional default value or use "auto" when nothing is provided
 * @returns {String} string output
 */
export declare function findWidthOrDefault(inputWidth?: number | string | null, defaultValue?: string): string;
/**
 * HTML encode using a plain <div>
 * Create a in-memory div, set it's inner text(which a div can encode)
 * then grab the encoded contents back out.  The div never exists on the page.
 * @param {String} inputValue - input value to be encoded
 * @return {String}
 */
export declare function htmlEncode(inputValue: string): string;
/**
 * Decode text into html entity
 * @param string text: input text
 * @param string text: output text
 */
export declare function htmlEntityDecode(input: string): string;
/**
 * Encode string to html special char and add html space padding defined
 * @param {string} inputStr - input string
 * @param {number} paddingLength - padding to add
 */
export declare function htmlEncodeWithPadding(inputStr: string, paddingLength: number): string;
/** insert an HTML Element after a target Element in the DOM */
export declare function insertAfterElement(referenceNode: HTMLElement, newNode: HTMLElement): void;
/**
 * Get the Window Scroll top/left Position
 * @returns
 */
export declare function windowScrollPosition(): {
    left: number;
    top: number;
};
//# sourceMappingURL=domUtils.d.ts.map